@@ -18,6 +18,7 @@
  */
 require_once 'PEAR.php';
 require_once 'PEAR/XMLParser.php';
+require_once 'PEAR/Proxy.php';
 
 /**
  * Intelligently retrieve data, following hyperlinks if necessary, and re-directing
@@ -356,26 +357,13 @@ class PEAR_REST
         $path   = isset($info['path']) ? $info['path'] : null;
         $schema = (isset($info['scheme']) && $info['scheme'] == 'https') ? 'https' : 'http';
 
-        $proxy_host = $proxy_port = $proxy_user = $proxy_pass = '';
-        if ($this->config->get('http_proxy')&&
-              $proxy = parse_url($this->config->get('http_proxy'))
-        ) {
-            $proxy_host = isset($proxy['host']) ? $proxy['host'] : null;
-            if ($schema === 'https') {
-                $proxy_host = 'ssl://' . $proxy_host;
-            }
-
-            $proxy_port   = isset($proxy['port']) ? $proxy['port'] : 8080;
-            $proxy_user   = isset($proxy['user']) ? urldecode($proxy['user']) : null;
-            $proxy_pass   = isset($proxy['pass']) ? urldecode($proxy['pass']) : null;
-            $proxy_schema = (isset($proxy['scheme']) && $proxy['scheme'] == 'https') ? 'https' : 'http';
-        }
+        $proxy = new PEAR_Proxy($this->config);
 
         if (empty($port)) {
             $port = (isset($info['scheme']) && $info['scheme'] == 'https')  ? 443 : 80;
         }
 
-        if (isset($proxy['host'])) {
+        if ($proxy->isProxyConfigured() && $schema === 'http') {
             $request = "GET $url HTTP/1.1\r\n";
         } else {
             $request = "GET $path HTTP/1.1\r\n";
@@ -406,9 +394,10 @@ class PEAR_REST
             $request .= "Authorization: Basic $tmp\r\n";
         }
 
-        if ($proxy_host != '' && $proxy_user != '') {
+        $proxyAuth = $proxy->getProxyAuth();
+        if ($proxyAuth) {
             $request .= 'Proxy-Authorization: Basic ' .
-                base64_encode($proxy_user . ':' . $proxy_pass) . "\r\n";
+                $proxyAuth . "\r\n";
         }
 
         if ($accept) {
@@ -419,20 +408,10 @@ class PEAR_REST
         $request .= "Connection: close\r\n";
         $request .= "\r\n";
 
-        if ($proxy_host != '') {
-            $fp = @fsockopen($proxy_host, $proxy_port, $errno, $errstr, 15);
-            if (!$fp) {
-                return PEAR::raiseError("Connection to `$proxy_host:$proxy_port' failed: $errstr", -9276);
-            }
-        } else {
-            if ($schema === 'https') {
-                $host = 'ssl://' . $host;
-            }
-
-            $fp = @fsockopen($host, $port, $errno, $errstr);
-            if (!$fp) {
-                return PEAR::raiseError("Connection to `$host:$port' failed: $errstr", $errno);
-            }
+        $secure = ($schema == 'https');
+        $fp = $proxy->openSocket($host, $port, $secure);
+        if (PEAR::isError($fp)) {
+            return $fp;
         }
 
         fwrite($fp, $request);
